@@ -183,7 +183,10 @@ fn rustc_flags(metadata: &Metadata, package: &Package, target: &Target) -> Resul
     let output = {
         remove_example(metadata, package, target)?;
 
-        cargo::build(&format!("example `{}`", target.name), false)
+        // smoelius: Because of lazy initialization, `cargo build` is run only once. Seeing
+        // "Building example `target`" for one example but not for others is confusing. So instead
+        // say "Building `package` examples".
+        cargo::build(&format!("`{}` examples", package.name), false)
             .envs(vec![(env::CARGO_TERM_COLOR, "never")])
             .args(&[
                 "--manifest-path",
@@ -210,7 +213,7 @@ fn rustc_flags(metadata: &Metadata, package: &Package, target: &Target) -> Resul
                     && args
                         .as_slice()
                         .windows(2)
-                        .any(|window| window == ["--crate-name", &target.name])
+                        .any(|window| window == ["--crate-name", &snake_case(&target.name)])
                 {
                     Some(args)
                 } else {
@@ -241,8 +244,9 @@ fn remove_example(metadata: &Metadata, _package: &Package, target: &Target) -> R
 
         if let Some(file_name) = path.file_name() {
             let s = file_name.to_string_lossy();
-            if s == target.name.clone() + consts::EXE_SUFFIX
-                || s.starts_with(&(target.name.clone() + "-"))
+            let target_name = snake_case(&target.name);
+            if s == target_name.clone() + consts::EXE_SUFFIX
+                || s.starts_with(&(target_name.clone() + "-"))
             {
                 remove_file(&path).with_context(|| {
                     format!("`remove_file` failed for `{}`", path.to_string_lossy())
@@ -289,3 +293,7 @@ fn run_tests<'test>(
     };
     compiletest::run_tests(&config);
 }
+
+fn snake_case(name: &str) -> String {
+    name.replace('-', "_")
+}
